@@ -21,6 +21,8 @@ import ssl
 import sys
 import traceback
 import uuid
+import dns.resolver
+import random
 import logging
 
 
@@ -312,16 +314,16 @@ class TalosHttpClient(TTransportBase):
 
     def open(self):
         if self.scheme == 'http':
-            self.__http = http_client.HTTPConnection(self.host, self.port,
-                                                     timeout=self.__timeout)
+            self.__http = http_client.HTTPConnection(self.get_addr_by_host(self.host),
+                                                     self.port, timeout=self.__timeout)
         elif self.scheme == 'https':
-            self.__http = http_client.HTTPSConnection(self.host, self.port,
-                                                      key_file=self.keyfile,
+            self.__http = http_client.HTTPSConnection(self.get_addr_by_host(self.host),
+                                                      self.port, key_file=self.keyfile,
                                                       cert_file=self.certfile,
                                                       timeout=self.__timeout,
                                                       context=self.context)
         if self.using_proxy():
-            self.__http.set_tunnel(self.realhost, self.realport,
+            self.__http.set_tunnel(self.get_addr_by_host(self.realhost), self.realport,
                                    {"Proxy-Authorization": self.proxy_auth})
 
     def close(self):
@@ -415,3 +417,22 @@ class TalosHttpClient(TTransportBase):
     def set_sid(self, sid=None):
         self._sid = sid
 
+    # for dns cache
+    def get_addr_by_host(self, host=None):
+        ipList = []
+        try:
+            A = dns.resolver.query(host)
+            if len(A.response.answer) > 0:
+                for items in A.response.answer:
+                    for item in items:
+                        ipList.append(item)
+                return str(random.choice(ipList))
+        except Exception as e:
+            self.logger.info("dns resolve error for host: "
+                             + host + str(traceback.format_exc()))
+        return host
+
+
+
+
+
